@@ -5,10 +5,12 @@ import { connect } from 'react-redux'
 
 import VmUserMessages from '../VmUserMessages'
 import UserMenu from './UserMenu'
+import Header from '../Header'
 import { hrefWithoutHistory } from '_/helpers'
 
 import { refresh } from '_/actions'
-import * as branding from '_/branding'
+import { msg } from '_/intl'
+import OverlayTooltip from '../OverlayTooltip'
 
 /**
  * Main application header on top of the page
@@ -16,27 +18,21 @@ import * as branding from '_/branding'
 const VmsPageHeader = ({ page, onRefresh }) => {
   const idPrefix = `pageheader`
   return (
-    <nav className='navbar obrand_mastheadBackground obrand_topBorder navbar-pf-vertical'>
-      <div className='navbar-header'>
-        <a href='/' className='navbar-brand obrand_headerLogoLink' id={`${idPrefix}-logo`}>
-          <img className='obrand_mastheadLogo' src={branding.resourcesUrls.clearGif} />
-        </a>
-      </div>
-
+    <Header>
       <div className='collapse navbar-collapse'>
         <ul className='nav navbar-nav navbar-right navbar-iconic'>
           <li>
-            <a href='#' className='nav-item-iconic' onClick={hrefWithoutHistory(() => onRefresh(page))} id={`${idPrefix}-refresh`}>
-              <i className='fa fa-refresh' />
-            </a>
+            <OverlayTooltip id={`${idPrefix}-tooltip`} tooltip={msg.refresh()} placement='bottom'>
+              <a href='#' className='nav-item-iconic' onClick={hrefWithoutHistory(() => onRefresh(page))} id={`${idPrefix}-refresh`}>
+                <i className='fa fa-refresh' />
+              </a>
+            </OverlayTooltip>
           </li>
-
           <UserMenu />
           <VmUserMessages />
         </ul>
       </div>
-
-    </nav>
+    </Header>
   )
 }
 VmsPageHeader.propTypes = {
